| Title: | Documents Files |
|---|---|
| Description: | It is sometimes necessary to create documentation for all files in a directory. Doing so by hand can be very tedious. This task is made fast and reproducible using the functionality of 'documenter'. It aggregates all text files in a directory and its subdirectories into a single word document in a semi-automated fashion. |
| Authors: | Zachary Colburn [aut, cre], Madigan Army Medical Center - Department of Clinical Investigation [cph, fnd] |
| Maintainer: | Zachary Colburn <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.3 |
| Built: | 2026-05-22 18:51:47 UTC |
| Source: | https://github.com/mamc-dci/documenter |
Create a template annotation file.
create_annotation_file(title = NULL, annotation_file = NULL)create_annotation_file(title = NULL, annotation_file = NULL)
title |
The title within the documentation file. |
annotation_file |
The path to the annotation file to be written. |
## Not run: create_annotation_file()## Not run: create_annotation_file()
Generate documentation for the files of a directory.
document_it(input_directory, output_file, annotation_file = NULL, title = NULL)document_it(input_directory, output_file, annotation_file = NULL, title = NULL)
input_directory |
The directory of files to be documented. |
output_file |
The path to the output file that will be generated. |
annotation_file |
The path to the annotation file if present. |
title |
The title of the output document. |
## Not run: input <- system.file("extdata", "example", package = "documenter") document_it( input_directory = input, output_file = "documentation", annotation_file = NULL ) ## End(Not run)## Not run: input <- system.file("extdata", "example", package = "documenter") document_it( input_directory = input, output_file = "documentation", annotation_file = NULL ) ## End(Not run)
Extract annotations from a yaml annotation file.
extract_annotations(annotation_yml, title)extract_annotations(annotation_yml, title)
annotation_yml |
The yaml object read by document_it. |
title |
The title of the output document. |
Fix a file path.
fix_path(path)fix_path(path)
path |
The path needing to be fixed. |
Insert each element of a vector into a document as a string of paragraphs.
insert_paragraphs(denv, vec)insert_paragraphs(denv, vec)
denv |
The environment of the input docx object. |
vec |
The character vector to be inserted. Each element should correspond to a separate paragraph. |
## Not run: insert_paragraphs(obj, vec) ## End(Not run)## Not run: insert_paragraphs(obj, vec) ## End(Not run)